package Bundle::Locale::CLDR::Easternafrica;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Easternafrica

=head1 CONTENTS

Locale::CLDR::Locales::Aa 0.46.0

Locale::CLDR::Locales::Am 0.46.0

Locale::CLDR::Locales::Ar 0.46.0

Locale::CLDR::Locales::Fr 0.46.0

Locale::CLDR::Locales::Ki 0.46.0

Locale::CLDR::Locales::Lg 0.46.0

Locale::CLDR::Locales::Mg 0.46.0

Locale::CLDR::Locales::Nd 0.46.0

Locale::CLDR::Locales::Ny 0.46.0

Locale::CLDR::Locales::Om 0.46.0

Locale::CLDR::Locales::Pt 0.46.0

Locale::CLDR::Locales::Rn 0.46.0

Locale::CLDR::Locales::Rw 0.46.0

Locale::CLDR::Locales::Sn 0.46.0

Locale::CLDR::Locales::So 0.46.0

Locale::CLDR::Locales::Sw 0.46.0

Locale::CLDR::Locales::Ti 0.46.0

Locale::CLDR::Locales::Asa 0.46.0

Locale::CLDR::Locales::Bem 0.46.0

Locale::CLDR::Locales::Bez 0.46.0

Locale::CLDR::Locales::Byn 0.46.0

Locale::CLDR::Locales::Cgg 0.46.0

Locale::CLDR::Locales::Dav 0.46.0

Locale::CLDR::Locales::Ebu 0.46.0

Locale::CLDR::Locales::Gez 0.46.0

Locale::CLDR::Locales::Guz 0.46.0

Locale::CLDR::Locales::Jmc 0.46.0

Locale::CLDR::Locales::Kam 0.46.0

Locale::CLDR::Locales::Kde 0.46.0

Locale::CLDR::Locales::Kln 0.46.0

Locale::CLDR::Locales::Ksb 0.46.0

Locale::CLDR::Locales::Lag 0.46.0

Locale::CLDR::Locales::Luo 0.46.0

Locale::CLDR::Locales::Luy 0.46.0

Locale::CLDR::Locales::Mas 0.46.0

Locale::CLDR::Locales::Mer 0.46.0

Locale::CLDR::Locales::Mfe 0.46.0

Locale::CLDR::Locales::Mgh 0.46.0

Locale::CLDR::Locales::Nus 0.46.0

Locale::CLDR::Locales::Nyn 0.46.0

Locale::CLDR::Locales::Rof 0.46.0

Locale::CLDR::Locales::Rwk 0.46.0

Locale::CLDR::Locales::Saq 0.46.0

Locale::CLDR::Locales::Sbp 0.46.0

Locale::CLDR::Locales::Seh 0.46.0

Locale::CLDR::Locales::Sid 0.46.0

Locale::CLDR::Locales::Ssy 0.46.0

Locale::CLDR::Locales::Teo 0.46.0

Locale::CLDR::Locales::Tig 0.46.0

Locale::CLDR::Locales::Vmw 0.46.0

Locale::CLDR::Locales::Vun 0.46.0

Locale::CLDR::Locales::Wal 0.46.0

Locale::CLDR::Locales::Xog 0.46.0

Locale::CLDR::Locales::Aa::Latn 0.46.0

Locale::CLDR::Locales::Am::Ethi 0.46.0

Locale::CLDR::Locales::Ar::Arab 0.46.0

Locale::CLDR::Locales::Fr::Latn 0.46.0

Locale::CLDR::Locales::Ki::Latn 0.46.0

Locale::CLDR::Locales::Lg::Latn 0.46.0

Locale::CLDR::Locales::Mg::Latn 0.46.0

Locale::CLDR::Locales::Nd::Latn 0.46.0

Locale::CLDR::Locales::Ny::Latn 0.46.0

Locale::CLDR::Locales::Om::Latn 0.46.0

Locale::CLDR::Locales::Pt::Latn 0.46.0

Locale::CLDR::Locales::Rn::Latn 0.46.0

Locale::CLDR::Locales::Rw::Latn 0.46.0

Locale::CLDR::Locales::Sn::Latn 0.46.0

Locale::CLDR::Locales::So::Latn 0.46.0

Locale::CLDR::Locales::Sw::Latn 0.46.0

Locale::CLDR::Locales::Ti::Ethi 0.46.0

Locale::CLDR::Locales::Asa::Latn 0.46.0

Locale::CLDR::Locales::Bem::Latn 0.46.0

Locale::CLDR::Locales::Bez::Latn 0.46.0

Locale::CLDR::Locales::Byn::Ethi 0.46.0

Locale::CLDR::Locales::Cgg::Latn 0.46.0

Locale::CLDR::Locales::Dav::Latn 0.46.0

Locale::CLDR::Locales::Ebu::Latn 0.46.0

Locale::CLDR::Locales::Gez::Ethi 0.46.0

Locale::CLDR::Locales::Guz::Latn 0.46.0

Locale::CLDR::Locales::Jmc::Latn 0.46.0

Locale::CLDR::Locales::Kam::Latn 0.46.0

Locale::CLDR::Locales::Kde::Latn 0.46.0

Locale::CLDR::Locales::Kln::Latn 0.46.0

Locale::CLDR::Locales::Ksb::Latn 0.46.0

Locale::CLDR::Locales::Lag::Latn 0.46.0

Locale::CLDR::Locales::Luo::Latn 0.46.0

Locale::CLDR::Locales::Luy::Latn 0.46.0

Locale::CLDR::Locales::Mas::Latn 0.46.0

Locale::CLDR::Locales::Mer::Latn 0.46.0

Locale::CLDR::Locales::Mfe::Latn 0.46.0

Locale::CLDR::Locales::Mgh::Latn 0.46.0

Locale::CLDR::Locales::Nus::Latn 0.46.0

Locale::CLDR::Locales::Nyn::Latn 0.46.0

Locale::CLDR::Locales::Rof::Latn 0.46.0

Locale::CLDR::Locales::Rwk::Latn 0.46.0

Locale::CLDR::Locales::Saq::Latn 0.46.0

Locale::CLDR::Locales::Sbp::Latn 0.46.0

Locale::CLDR::Locales::Seh::Latn 0.46.0

Locale::CLDR::Locales::Sid::Latn 0.46.0

Locale::CLDR::Locales::Ssy::Latn 0.46.0

Locale::CLDR::Locales::Teo::Latn 0.46.0

Locale::CLDR::Locales::Tig::Ethi 0.46.0

Locale::CLDR::Locales::Vmw::Latn 0.46.0

Locale::CLDR::Locales::Vun::Latn 0.46.0

Locale::CLDR::Locales::Wal::Ethi 0.46.0

Locale::CLDR::Locales::Xog::Latn 0.46.0

Locale::CLDR::Locales::Aa::Latn::Dj 0.46.0

Locale::CLDR::Locales::Aa::Latn::Er 0.46.0

Locale::CLDR::Locales::Aa::Latn::Et 0.46.0

Locale::CLDR::Locales::Am::Ethi::Et 0.46.0

Locale::CLDR::Locales::Ar::Arab::Dj 0.46.0

Locale::CLDR::Locales::Ar::Arab::Er 0.46.0

Locale::CLDR::Locales::Ar::Arab::Km 0.46.0

Locale::CLDR::Locales::Ar::Arab::So 0.46.0

Locale::CLDR::Locales::Ar::Arab::Ss 0.46.0

Locale::CLDR::Locales::En::Latn::Bi 0.46.0

Locale::CLDR::Locales::En::Latn::Er 0.46.0

Locale::CLDR::Locales::En::Latn::Io 0.46.0

Locale::CLDR::Locales::En::Latn::Ke 0.46.0

Locale::CLDR::Locales::En::Latn::Mg 0.46.0

Locale::CLDR::Locales::En::Latn::Mu 0.46.0

Locale::CLDR::Locales::En::Latn::Mw 0.46.0

Locale::CLDR::Locales::En::Latn::Rw 0.46.0

Locale::CLDR::Locales::En::Latn::Sc 0.46.0

Locale::CLDR::Locales::En::Latn::Ss 0.46.0

Locale::CLDR::Locales::En::Latn::Tz 0.46.0

Locale::CLDR::Locales::En::Latn::Ug 0.46.0

Locale::CLDR::Locales::En::Latn::Zm 0.46.0

Locale::CLDR::Locales::En::Latn::Zw 0.46.0

Locale::CLDR::Locales::Fr::Latn::Bi 0.46.0

Locale::CLDR::Locales::Fr::Latn::Dj 0.46.0

Locale::CLDR::Locales::Fr::Latn::Km 0.46.0

Locale::CLDR::Locales::Fr::Latn::Mg 0.46.0

Locale::CLDR::Locales::Fr::Latn::Mu 0.46.0

Locale::CLDR::Locales::Fr::Latn::Re 0.46.0

Locale::CLDR::Locales::Fr::Latn::Rw 0.46.0

Locale::CLDR::Locales::Fr::Latn::Sc 0.46.0

Locale::CLDR::Locales::Fr::Latn::Yt 0.46.0

Locale::CLDR::Locales::Ki::Latn::Ke 0.46.0

Locale::CLDR::Locales::Lg::Latn::Ug 0.46.0

Locale::CLDR::Locales::Mg::Latn::Mg 0.46.0

Locale::CLDR::Locales::Nd::Latn::Zw 0.46.0

Locale::CLDR::Locales::Ny::Latn::Mw 0.46.0

Locale::CLDR::Locales::Om::Latn::Et 0.46.0

Locale::CLDR::Locales::Om::Latn::Ke 0.46.0

Locale::CLDR::Locales::Pt::Latn::Mz 0.46.0

Locale::CLDR::Locales::Pt::Latn::Pt 0.46.0

Locale::CLDR::Locales::Rn::Latn::Bi 0.46.0

Locale::CLDR::Locales::Rw::Latn::Rw 0.46.0

Locale::CLDR::Locales::Sn::Latn::Zw 0.46.0

Locale::CLDR::Locales::So::Latn::Dj 0.46.0

Locale::CLDR::Locales::So::Latn::Et 0.46.0

Locale::CLDR::Locales::So::Latn::Ke 0.46.0

Locale::CLDR::Locales::So::Latn::So 0.46.0

Locale::CLDR::Locales::Sw::Latn::Ke 0.46.0

Locale::CLDR::Locales::Sw::Latn::Tz 0.46.0

Locale::CLDR::Locales::Sw::Latn::Ug 0.46.0

Locale::CLDR::Locales::Ti::Ethi::Er 0.46.0

Locale::CLDR::Locales::Ti::Ethi::Et 0.46.0

Locale::CLDR::Locales::Asa::Latn::Tz 0.46.0

Locale::CLDR::Locales::Bem::Latn::Zm 0.46.0

Locale::CLDR::Locales::Bez::Latn::Tz 0.46.0

Locale::CLDR::Locales::Byn::Ethi::Er 0.46.0

Locale::CLDR::Locales::Cgg::Latn::Ug 0.46.0

Locale::CLDR::Locales::Dav::Latn::Ke 0.46.0

Locale::CLDR::Locales::Ebu::Latn::Ke 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0

Locale::CLDR::Locales::Gez::Ethi::Er 0.46.0

Locale::CLDR::Locales::Gez::Ethi::Et 0.46.0

Locale::CLDR::Locales::Guz::Latn::Ke 0.46.0

Locale::CLDR::Locales::Jmc::Latn::Tz 0.46.0

Locale::CLDR::Locales::Kam::Latn::Ke 0.46.0

Locale::CLDR::Locales::Kde::Latn::Tz 0.46.0

Locale::CLDR::Locales::Kln::Latn::Ke 0.46.0

Locale::CLDR::Locales::Ksb::Latn::Tz 0.46.0

Locale::CLDR::Locales::Lag::Latn::Tz 0.46.0

Locale::CLDR::Locales::Luo::Latn::Ke 0.46.0

Locale::CLDR::Locales::Luy::Latn::Ke 0.46.0

Locale::CLDR::Locales::Mas::Latn::Ke 0.46.0

Locale::CLDR::Locales::Mas::Latn::Tz 0.46.0

Locale::CLDR::Locales::Mer::Latn::Ke 0.46.0

Locale::CLDR::Locales::Mfe::Latn::Mu 0.46.0

Locale::CLDR::Locales::Mgh::Latn::Mz 0.46.0

Locale::CLDR::Locales::Nus::Latn::Ss 0.46.0

Locale::CLDR::Locales::Nyn::Latn::Ug 0.46.0

Locale::CLDR::Locales::Rof::Latn::Tz 0.46.0

Locale::CLDR::Locales::Rwk::Latn::Tz 0.46.0

Locale::CLDR::Locales::Saq::Latn::Ke 0.46.0

Locale::CLDR::Locales::Sbp::Latn::Tz 0.46.0

Locale::CLDR::Locales::Seh::Latn::Mz 0.46.0

Locale::CLDR::Locales::Sid::Latn::Et 0.46.0

Locale::CLDR::Locales::Ssy::Latn::Er 0.46.0

Locale::CLDR::Locales::Teo::Latn::Ke 0.46.0

Locale::CLDR::Locales::Teo::Latn::Ug 0.46.0

Locale::CLDR::Locales::Tig::Ethi::Er 0.46.0

Locale::CLDR::Locales::Vmw::Latn::Mz 0.46.0

Locale::CLDR::Locales::Vun::Latn::Tz 0.46.0

Locale::CLDR::Locales::Wal::Ethi::Et 0.46.0

Locale::CLDR::Locales::Xog::Latn::Ug 0.46.0


=cut

1;

